import { json, select, scaleLinear, scalePoint, min, max } from 'd3';
const jsonURL =
  'https://gist.githubusercontent.com/waseem-medhat/61e0416f6ed7ac64eb2872093c3bf8da/raw/ww2020-11-11_metadata.json';

const width = 960;
const height = 500;
const margin = { top: 100, right: 40, bottom: 100, left: 40 };
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;

json(jsonURL).then((dataArr) => {
  const data = dataArr.slice(0)
  
  const xScale = scaleLinear()
    .domain([min(data, (d) => d.OR_lo), max(data, (d) => d.OR_hi)])
    .range([0, innerWidth]);

  const yScale = scalePoint()
    .domain(data.map((d) => d.STUDYID))
    .range([0, innerHeight])
  	.padding(0.8);

  const svg = select('body')
    .append('svg')
    .attr('width', width)
    .attr('height', height);

  const g = svg
    .append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

  g.selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('x', (d) => xScale(d.OR_lo))
  	.attr('width', (d) => xScale(d.OR_hi) - xScale(d.OR_lo))
  	.attr('height', innerHeight)
  	.attr('fill', '#000C66')
  	.attr('opacity', 1 / data.length)
  
  g.selectAll('line')
    .data(data)
    .enter()
    .append('line')
    .attr('transform', (d) => `translate(0,${yScale(d.STUDYID)})`)
    .attr('x1', (d) => xScale(d.OR_lo))
    .attr('x2', (d) => xScale(d.OR_hi))
    .attr('stroke', '#eee')
  	.attr('stroke-width', 3);
});
